@@ -1,3 +1,2 @@
-import utils
-import filter
+from . import *
 from mongonow.client import MongoNowClient
